@@ -124,13 +124,21 @@ class Postprocessing(object):
 		self.raster.add_data_grid("stops_nb",int,0) #store the number of stops per cell
 		self.raster.add_data_grid("stops_origin",list) #at each stop cell, store a list of START cell coordinates
 		self.raster.add_data_grid("Ec",list) #Kinetic energy
+		self.raster.add_data_grid("nb_trees_impacts",int,0)
+		self.raster.add_data_grid("trees_impacts_max_height",float,0)
 		for r_nb in range(self.simulation.nb_rocks):
 			
 			c_pos   = self.simulation.output.get_contacts_pos(r_nb)
 			c_types = self.simulation.output.get_contacts_types(r_nb)
+			c_tree_ids = np.where(np.logical_or(c_types==Out.TREE,c_types==Out.ROLL_TREE))[0]
 			
 			#find cells from contacts pos. raster_indices will be the consecutive list of raster indices the rock has crossed.
 			raster_indices = self.get_raster_indices_from_contacts(c_pos,c_types)
+			for tree_id in c_tree_ids:
+				raster_id=raster_indices[tree_id]
+				height=c_pos[tree_id][2]-self.raster.data["Z"][raster_id[0],raster_id[1]]
+				self.raster.data["nb_trees_impacts"][raster_id[0],raster_id[1]]+=1
+				self.raster.data["trees_impacts_max_height"][raster_id[0],raster_id[1]]=max( self.raster.data["trees_impacts_max_height"][raster_id[0],raster_id[1]], height )
 			
 			#CLEANING PASS : when consecutive contacts on the same raster cell occurs, only keep the first one and the last one
 			indices_duplicates_removed=self.get_indices_cleaned(raster_indices)
